Project to create manifest file
-------

Instructions:

Update the mozart_ids.txt file with the list of mozard ids. These ids can be categorized by the device type by adding the separate 
such as '[Raven]'. This will create a manifest file Raven_manifest.xml. You can add multiple separators in the file and that will 
generate multiple manifests files in data folder. Refer to the sample mozart_ids.txt file that is included with this package. 

To run, use the command 'python3 core.py' from under the src director.